function varargout = Magnitudes(varargin)
% MAGNITUDES M-file for Magnitudes.fig
%      MAGNITUDES, by itself, creates a new MAGNITUDES or raises the existing
%      singleton*.
%
%      H = MAGNITUDES returns the handle to a new MAGNITUDES or the handle to
%      the existing singleton*.
%
%      MAGNITUDES('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MAGNITUDES.M with the given input arguments.
%
%      MAGNITUDES('Property','Value',...) creates a new MAGNITUDES or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Magnitudes_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Magnitudes_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES
% Copyright 2002-2003 The MathWorks, Inc.
% Edit the above text to modify the response to help Magnitudes
% Last Modified by GUIDE v2.5 12-Dec-2005 23:50:23

%DEFINICIÓN DE FUNCIÓN
%Función que nos permite crear la Magnitudes

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Magnitudes_OpeningFcn, ...
                   'gui_OutputFcn',  @Magnitudes_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Magnitudes is made visible.
function Magnitudes_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Magnitudes (see VARARGIN)
% Choose default command line output for Magnitudes
handles.output = hObject;
%Por defecto ponemos una imagen en la Magnitudes
A=imread('logo','jpeg');
B=imread('logoesi','bmp');
axes(handles.Figura_axes)
image(A);
axes(handles.logoescuela)
image(B)
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Magnitudes wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Magnitudes_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in ayuda_push.
function ayuda_push_Callback(hObject, eventdata, handles)
% hObject    handle to ayuda_push (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
helpdlg('AYUDA: Pulse Siguiente para comenzar el procesado','AYUDA');



% --- Executes on button press in siguiente_push.
function siguiente_push_Callback(hObject, eventdata, handles)
% hObject    handle to siguiente_push (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close all
clear all
procesado;



% --- Executes on button press in Cancelar_push.
function Cancelar_push_Callback(hObject, eventdata, handles)
% hObject    handle to Cancelar_push (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
closereq

